@@ -13,8 +13,72 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-"""A notification listener exposes a number of endpoints, each of which
-contain a set of methods. Each method corresponds to a notification priority.
+
+r"""A notification listener is used to process notification messages sent by a
+notifier that uses the ``messaging`` driver.
+
+A notification listener subscribes to the topic - and optionally exchange - in
+the supplied target.  Notification messages sent by notifier clients to the
+target's topic/exchange are received by the listener.
+
+A notification listener exposes a number of endpoints, each of which contain a
+set of methods. Each method's name corresponds to a notification's priority.
+When a notification is received it is dispatched to the method named like the
+notification's priority - e.g. ``info`` notifications are dispatched to the
+info() method, etc.
+
+Optionally a notification endpoint can define a NotificationFilter.
+Notification messages that do not match the filter's rules will *not* be passed
+to the endpoint's methods.
+
+Parameters to endpoint methods are: the request context supplied by the client,
+the publisher_id of the notification message, the event_type, the payload and
+metadata. The metadata parameter is a mapping containing a unique message_id
+and a timestamp.
+
+An endpoint method can explicitly return
+oslo_messaging.NotificationResult.HANDLED to acknowledge a message or
+oslo_messaging.NotificationResult.REQUEUE to requeue the message. Note that not
+all transport drivers implement support for requeueing. In order to use this
+feature, applications should assert that the feature is available by passing
+allow_requeue=True to get_notification_listener(). If the driver does not
+support requeueing, it will raise NotImplementedError at this point.
+
+The message is acknowledged only if all endpoints either return
+oslo_messaging.NotificationResult.HANDLED or None.
+
+*NOTE*: If multiple listeners subscribe to the same target, the notification
+will be received by only *one* of the listeners. The receiving listener is
+selected from the group using a best-effort round-robin algorithm.
+
+This delivery pattern can be altered somewhat by specifying a pool name for the
+listener. Listeners with the same pool name behave like a subgroup within the
+group of listeners subscribed to the same topic/exchange.  Each subgroup of
+listeners will receive a copy of the notification to be consumed by one member
+of the subgroup. Therefore, multiple copies of the notification will be
+delivered - one to the group of listeners that have no pool name (if they
+exist), and one to each subgroup of listeners that share the same pool name.
+
+**NOTE WELL:** This means that the Notifier always publishes notifications to a
+non-pooled Listener as well as the pooled Listeners. Therefore any application
+that uses listener pools **must have at least one listener that consumes from
+the non-pooled queue** (i.e. one or more listeners that do not set the *pool*
+parameter.
+
+Note that not all transport drivers have implemented support for listener
+pools. Those drivers that do not support pools will raise a NotImplementedError
+if a pool name is specified to get_notification_listener().
+
+Each notification listener is associated with an executor which controls how
+incoming notification messages will be received and dispatched. Refer to the
+Executor documentation for descriptions of the other types of executors.
+
+*Note:* If the "eventlet" executor is used, the threading and time library need
+to be monkeypatched.
+
+Notification listener have start(), stop() and wait() messages to begin
+handling requests, stop handling requests, and wait for all in-process
+requests to complete after the listener has been stopped.
 
 To create a notification listener, you supply a transport, list of targets and
 a list of endpoints.
@@ -27,32 +91,24 @@ method::
 which will load the appropriate transport driver according to the user's
 messaging configuration. See get_notification_transport() for more details.
 
-The target supplied when creating a notification listener expresses the topic
-and - optionally - the exchange to listen on. See Target for more details
-on these attributes.
-
-Notification listener have start(), stop() and wait() messages to begin
-handling requests, stop handling requests and wait for all in-process
-requests to complete.
-
-Each notification listener is associated with an executor which integrates the
-listener with a specific I/O handling framework. Currently, there are blocking
-and eventlet executors available.
-
 A simple example of a notification listener with multiple endpoints might be::
 
     from oslo_config import cfg
     import oslo_messaging
 
+
     class NotificationEndpoint(object):
-        filter_rule = NotificationFilter(publisher_id='^compute.*')
+        filter_rule = oslo_messaging.NotificationFilter(
+            publisher_id='^compute.*')
 
         def warn(self, ctxt, publisher_id, event_type, payload, metadata):
             do_something(payload)
 
+
     class ErrorEndpoint(object):
-        filter_rule = NotificationFilter(event_type='^instance\..*\.start$',
-                                         context={'ctxt_key': 'regexp'})
+        filter_rule = oslo_messaging.NotificationFilter(
+            event_type='^instance\..*\.start$',
+            context={'ctxt_key': 'regexp'})
 
         def error(self, ctxt, publisher_id, event_type, payload, metadata):
             do_something(payload)
@@ -68,57 +124,31 @@ A simple example of a notification listener with multiple endpoints might be::
     ]
     pool = "listener-workers"
     server = oslo_messaging.get_notification_listener(transport, targets,
-                                                      endpoints, pool)
+                                                      endpoints, pool=pool)
     server.start()
     server.wait()
 
-A notifier sends a notification on a topic with a priority, the notification
-listener will receive this notification if the topic of this one have been set
-in one of the targets and if an endpoint implements the method named like the
-priority and if the notification match the NotificationFilter rule set into
-the filter_rule attribute of the endpoint.
-
-Parameters to endpoint methods are the request context supplied by the client,
-the publisher_id of the notification message, the event_type, the payload and
-metadata. The metadata parameter is a mapping containing a unique message_id
-and a timestamp.
 
 By supplying a serializer object, a listener can deserialize a request context
-and arguments from - and serialize return values to - primitive types.
-
-By supplying a pool name you can create multiple groups of listeners consuming
-notifications and that each group only receives one copy of each
-notification.
-
-An endpoint method can explicitly return
-oslo_messaging.NotificationResult.HANDLED to acknowledge a message or
-oslo_messaging.NotificationResult.REQUEUE to requeue the message.
-
-The message is acknowledged only if all endpoints either return
-oslo_messaging.NotificationResult.HANDLED or None.
-
-Note that not all transport drivers implement support for requeueing. In order
-to use this feature, applications should assert that the feature is available
-by passing allow_requeue=True to get_notification_listener(). If the driver
-does not support requeueing, it will raise NotImplementedError at this point.
+and arguments from primitive types.
 
 """
 import itertools
 import logging
 
-from oslo_messaging._i18n import _LE
 from oslo_messaging.notify import dispatcher as notify_dispatcher
 from oslo_messaging import server as msg_server
+from oslo_messaging import transport as msg_transport
 
 LOG = logging.getLogger(__name__)
 
 
 class NotificationServerBase(msg_server.MessageHandlingServer):
-    def __init__(self, transport, targets, dispatcher, executor='blocking',
+    def __init__(self, transport, targets, dispatcher, executor=None,
                  allow_requeue=True, pool=None, batch_size=1,
                  batch_timeout=None):
-        super(NotificationServerBase, self).__init__(transport, dispatcher,
-                                                     executor)
+        super().__init__(transport, dispatcher,
+                         executor)
         self._allow_requeue = allow_requeue
         self._pool = pool
         self.targets = targets
@@ -138,9 +168,14 @@ class NotificationServerBase(msg_server.MessageHandlingServer):
 
 
 class NotificationServer(NotificationServerBase):
-    def __init__(self, transport, targets, dispatcher, executor='blocking',
+    def __init__(self, transport, targets, dispatcher, executor=None,
                  allow_requeue=True, pool=None):
-        super(NotificationServer, self).__init__(
+        if not isinstance(transport, msg_transport.NotificationTransport):
+            LOG.warning("Using RPC transport for notifications. Please use "
+                        "get_notification_transport to obtain a "
+                        "notification transport instance.")
+
+        super().__init__(
             transport, targets, dispatcher, executor, allow_requeue, pool, 1,
             None
         )
@@ -150,7 +185,7 @@ class NotificationServer(NotificationServerBase):
         try:
             res = self.dispatcher.dispatch(message)
         except Exception:
-            LOG.exception(_LE('Exception during message handling.'))
+            LOG.exception('Exception during message handling.')
             res = notify_dispatcher.NotificationResult.REQUEUE
 
         try:
@@ -160,7 +195,7 @@ class NotificationServer(NotificationServerBase):
             else:
                 message.acknowledge()
         except Exception:
-            LOG.exception(_LE("Fail to ack/requeue message."))
+            LOG.exception("Fail to ack/requeue message.")
 
 
 class BatchNotificationServer(NotificationServerBase):
@@ -170,7 +205,7 @@ class BatchNotificationServer(NotificationServerBase):
             not_processed_messages = self.dispatcher.dispatch(incoming)
         except Exception:
             not_processed_messages = set(incoming)
-            LOG.exception(_LE('Exception during messages handling.'))
+            LOG.exception('Exception during messages handling.')
         for m in incoming:
             try:
                 if m in not_processed_messages and self._allow_requeue:
@@ -178,17 +213,16 @@ class BatchNotificationServer(NotificationServerBase):
                 else:
                     m.acknowledge()
             except Exception:
-                LOG.exception(_LE("Fail to ack/requeue message."))
+                LOG.exception("Fail to ack/requeue message.")
 
 
 def get_notification_listener(transport, targets, endpoints,
-                              executor='blocking', serializer=None,
+                              executor=None, serializer=None,
                               allow_requeue=False, pool=None):
     """Construct a notification listener
 
     The executor parameter controls how incoming messages will be received and
-    dispatched. By default, the most simple executor is used - the blocking
-    executor.
+    dispatched.
 
     If the eventlet executor is used, the threading and time library need to be
     monkeypatched.
@@ -199,8 +233,8 @@ def get_notification_listener(transport, targets, endpoints,
     :type targets: list of Target
     :param endpoints: a list of endpoint objects
     :type endpoints: list
-    :param executor: name of a message executor - for example
-                     'eventlet', 'blocking'
+    :param executor: name of message executor - available values are
+                     'eventlet' and 'threading'
     :type executor: str
     :param serializer: an optional entity serializer
     :type serializer: Serializer
@@ -217,14 +251,13 @@ def get_notification_listener(transport, targets, endpoints,
 
 
 def get_batch_notification_listener(transport, targets, endpoints,
-                                    executor='blocking', serializer=None,
+                                    executor=None, serializer=None,
                                     allow_requeue=False, pool=None,
                                     batch_size=None, batch_timeout=None):
     """Construct a batch notification listener
 
     The executor parameter controls how incoming messages will be received and
-    dispatched. By default, the most simple executor is used - the blocking
-    executor.
+    dispatched.
 
     If the eventlet executor is used, the threading and time library need to be
     monkeypatched.
@@ -235,8 +268,8 @@ def get_batch_notification_listener(transport, targets, endpoints,
     :type targets: list of Target
     :param endpoints: a list of endpoint objects
     :type endpoints: list
-    :param executor: name of a message executor - for example
-                     'eventlet', 'blocking'
+    :param executor: name of message executor - available values are
+                     'eventlet' and 'threading'
     :type executor: str
     :param serializer: an optional entity serializer
     :type serializer: Serializer
