@@ -23,11 +23,9 @@ import traceback as tb
 
 from oslo_config import cfg
 from oslo_middleware import base
-import six
 import webob.dec
 
 import oslo_messaging
-from oslo_messaging._i18n import _LE
 from oslo_messaging import notify
 
 LOG = logging.getLogger(__name__)
@@ -38,8 +36,8 @@ def log_and_ignore_error(fn):
         try:
             return fn(*args, **kwargs)
         except Exception as e:
-            LOG.exception(_LE('An exception occurred processing '
-                              'the API call: %s ') % e)
+            LOG.exception('An exception occurred processing '
+                          'the API call: %s ', e)
     return wrapped
 
 
@@ -65,7 +63,7 @@ class RequestNotifier(base.Middleware):
         self.service_name = conf.get('service_name')
         self.ignore_req_list = [x.upper().strip() for x in
                                 conf.get('ignore_req_list', '').split(',')]
-        super(RequestNotifier, self).__init__(app)
+        super().__init__(app)
 
     @staticmethod
     def environ_to_dict(environ):
@@ -73,8 +71,8 @@ class RequestNotifier(base.Middleware):
         include them.
 
         """
-        return dict((k, v) for k, v in six.iteritems(environ)
-                    if k.isupper() and k != 'HTTP_X_AUTH_TOKEN')
+        return {k: v for k, v in environ.items()
+                if k.isupper() and k != 'HTTP_X_AUTH_TOKEN'}
 
     @log_and_ignore_error
     def process_request(self, request):
