@@ -32,6 +32,7 @@ __all__ = [
     'RPCClient',
     'RPCVersionCapError',
     'RemoteError',
+    'get_rpc_client',
 ]
 
 LOG = logging.getLogger(__name__)
@@ -59,7 +60,7 @@ class RemoteError(exceptions.MessagingException):
         msg = ("Remote error: %(exc_type)s %(value)s\n%(traceback)s." %
                dict(exc_type=self.exc_type, value=self.value,
                     traceback=self.traceback))
-        super(RemoteError, self).__init__(msg)
+        super().__init__(msg)
 
 
 class RPCVersionCapError(exceptions.MessagingException):
@@ -72,20 +73,20 @@ class RPCVersionCapError(exceptions.MessagingException):
                "in minor version as the specified version cap "
                "%(version_cap)s." %
                dict(version=self.version, version_cap=self.version_cap))
-        super(RPCVersionCapError, self).__init__(msg)
+        super().__init__(msg)
 
 
 class ClientSendError(exceptions.MessagingException):
     """Raised if we failed to send a message to a target."""
 
     def __init__(self, target, ex):
-        msg = 'Failed to send to target "%s": %s' % (target, ex)
-        super(ClientSendError, self).__init__(msg)
+        msg = 'Failed to send to target "{}": {}'.format(target, ex)
+        super().__init__(msg)
         self.target = target
         self.ex = ex
 
 
-class _BaseCallContext(object, metaclass=abc.ABCMeta):
+class _BaseCallContext(metaclass=abc.ABCMeta):
 
     _marker = object()
 
@@ -103,7 +104,7 @@ class _BaseCallContext(object, metaclass=abc.ABCMeta):
         self.version_cap = version_cap
         self.transport_options = transport_options
 
-        super(_BaseCallContext, self).__init__()
+        super().__init__()
 
     def _make_message(self, ctxt, method, args):
         msg = dict(method=method)
@@ -226,8 +227,8 @@ class _CallContext(_BaseCallContext):
             version=version,
             server=server,
             fanout=fanout)
-        kwargs = dict([(k, v) for k, v in kwargs.items()
-                       if v is not cls._marker])
+        kwargs = {k: v for k, v in kwargs.items()
+                  if v is not cls._marker}
         target = call_context.target(**kwargs)
 
         if timeout is cls._marker:
@@ -263,6 +264,9 @@ class RPCClient(_BaseCallContext):
     The RPCClient class is responsible for sending method invocations to and
     receiving return values from remote RPC servers via a messaging transport.
 
+    The class should always be instantiated by using the get_rpc_client
+    function and not constructing the class directly.
+
     Two RPC patterns are supported: RPC calls and RPC casts.
 
     An RPC cast is used when an RPC method does *not* return a value to
@@ -295,7 +299,7 @@ class RPCClient(_BaseCallContext):
 
             def __init__(self, transport):
                 target = messaging.Target(topic='test', version='2.0')
-                self._client = messaging.RPCClient(transport, target)
+                self._client = messaging.get_rpc_client(transport, target)
 
             def test(self, ctxt, arg):
                 return self._client.call(ctxt, 'test', arg=arg)
@@ -320,7 +324,7 @@ class RPCClient(_BaseCallContext):
 
         transport = messaging.get_rpc_transport(cfg.CONF)
         target = messaging.Target(topic='test', version='2.0')
-        client = messaging.RPCClient(transport, target)
+        client = messaging.get_rpc_client(transport, target)
         client.call(ctxt, 'test', arg=arg)
 
     but this is probably only useful in limited circumstances as a wrapper
@@ -334,7 +338,7 @@ class RPCClient(_BaseCallContext):
     have the RPC request fail with a MessageDeliveryFailure after the given
     number of retries. For example::
 
-        client = messaging.RPCClient(transport, target, retry=None)
+        client = messaging.get_rpc_client(transport, target, retry=None)
         client.call(ctxt, 'sync')
         try:
             client.prepare(retry=0).cast(ctxt, 'ping')
@@ -346,9 +350,13 @@ class RPCClient(_BaseCallContext):
 
     def __init__(self, transport, target,
                  timeout=None, version_cap=None, serializer=None, retry=None,
-                 call_monitor_timeout=None, transport_options=None):
+                 call_monitor_timeout=None, transport_options=None,
+                 _manual_load=True):
         """Construct an RPC client.
 
+        This should not be called directly, use the get_rpc_client function
+        to instantiate this class.
+
         :param transport: a messaging transport handle
         :type transport: Transport
         :param target: the default target for invocations
@@ -371,7 +379,17 @@ class RPCClient(_BaseCallContext):
                                      (less than the overall timeout
                                      parameter).
         :type call_monitor_timeout: int
+        :param transport_options: Transport options passed to client.
+        :type transport_options: TransportOptions
+        :param _manual_load: Internal use only to check if class was
+                             manually instantiated or not.
+        :type _manual_load: bool
         """
+        if _manual_load:
+            LOG.warning("Using RPCClient manually to instantiate client. "
+                        "Please use get_rpc_client to obtain an RPC client "
+                        "instance.")
+
         if serializer is None:
             serializer = msg_serializer.NoOpSerializer()
 
@@ -380,7 +398,7 @@ class RPCClient(_BaseCallContext):
                         "get_rpc_transport to obtain an RPC transport "
                         "instance.")
 
-        super(RPCClient, self).__init__(
+        super().__init__(
             transport, target, serializer, timeout, version_cap, retry,
             call_monitor_timeout, transport_options
         )
@@ -530,3 +548,18 @@ class RPCClient(_BaseCallContext):
     def can_send_version(self, version=_marker):
         """Check to see if a version is compatible with the version cap."""
         return self.prepare(version=version).can_send_version()
+
+
+def get_rpc_client(transport, target, client_cls=RPCClient, **kwargs):
+    """Construct an RPC client.
+
+    :param transport: the messaging transport
+    :type transport: Transport
+    :param target: the exchange, topic and server to listen on
+    :type target: Target
+    :param client_cls: The client class to instantiate
+    :type client_cls: class
+    :param **kwargs: The kwargs will be passed down to the
+                     client_cls constructor
+    """
+    return client_cls(transport, target, _manual_load=False, **kwargs)
