@@ -13,14 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-# Import oslotest before importing test submodules to setup six.moves for mock
-import oslotest
+import eventlet
+eventlet.monkey_patch()
 
-try:
-    import eventlet
-except ImportError:
-    pass
-else:
-    # Ensure that eventlet monkey patching is enabled before loading the qpid
-    # module, otherwise qpid will hang
-    eventlet.monkey_patch()
+# oslotest prepares mock for six in oslotest/__init__.py as follow:
+# six.add_move(six.MovedModule('mock', 'mock', 'unittest.mock')) and
+# oslo.messaging imports oslotest before importing test submodules to
+# setup six.moves for mock, then "from unittest import mock" works well.
+import oslotest
